@@ -1,5 +1,5 @@
 #
-# $Id: Split.pm,v 0.3 2003/12/31 19:36:50 st.schubiger Exp $
+# $Id: Split.pm,v 0.31 2003/12/31 22:26:09 st.schubiger Exp $
 
 package Dir::Split;
 
@@ -46,7 +46,7 @@ our (# external refs
         $suffix,
     );
 
-our $VERSION = 0.3;
+our $VERSION = 0.31;
 
 =head1 NAME
 
@@ -59,7 +59,9 @@ Dir::Split - Split the files of a directory to subdirectories.
  # numeric options
  %behavior = (  mode    =>    'num',
 
-                options => {  verbose   =>  1,
+                options => {  verbose        =>           1,
+                              warn           =>       'all',
+                              override       =>      'none',
                 },
 
                 sub_dir => {  identifier     =>    'system',
@@ -76,14 +78,14 @@ Dir::Split - Split the files of a directory to subdirectories.
  # create object
  $dir = Dir::Split->new (\%behavior);
 
- # set source & target dirs
+ # set source & target dir
  $source_dir = '/var/tmp/src';
  $target_dir = '/var/tmp/target';
 
  # split files to subdirs
  $files_moved = $dir->split (\$source_dir, \$target_dir);
 
- # changes the subdir identifier
+ # change the subdir identifier
  $dir->{'sub_dir'}{'identifier'} = 'test';
 
  # split files to subdirs
@@ -115,6 +117,8 @@ See EXAMPLES to gain an understanding how numeric splitting works.
  %behavior = (  mode    =>    'num',
 
                 options => {  verbose        =>           1,
+                              warn           =>       'all',
+                              override       =>      'none',
                 },
 
                 sub_dir => {  identifier     =>    'system',
@@ -168,6 +172,26 @@ on creating subdirectories.
    0  disabled
    1  enabled
 
+=item C<options/warn>
+
+string - warn upon the encounter of existing files/dirs.
+
+ LEVELS
+   none
+   files
+   dirs
+   all
+
+=item C<options/override>
+
+string - override of existing files/dirs.
+
+ LEVELS
+   none
+   files
+   dirs
+   all
+
 =item C<sub_dir/identifier>
 
 string - prefix of each subdirectory created.
@@ -190,17 +214,17 @@ integer - limit of files per subdirectory.
 
 string - sorting order of files.
 
-  MODES
-    +  ascending sort order
-    -  descending sort order
+ MODES
+   +  ascending sort order
+   -  descending sort order
 
 =item C<suffix/continue_num>
 
 string - numbering continuation (will start at 1 if no).
 
-  MODES
-    y   yes
-    ''  no
+ MODES
+   y  yes
+   n  no
 
 =item C<suffix/length>
 
@@ -217,26 +241,6 @@ be continued, whereas C<identifier>, C<separator> and C<continue_num> do.
 
 =over 4
 
-=item C<options/warn>
-
-string - warn upon the encounter of existing files/dirs.
-
-  LEVELS
-    none
-    files
-    dirs
-    all
-
-=item C<options/override>
-
-string - override of existing files/dirs.
-
-  LEVELS
-    none
-    files
-    dirs
-    all
-
 =item C<suffix/case>
 
 string - lower/upper case of the suffix.
@@ -332,12 +336,67 @@ sub split {
     $path_ref = \$path;
     $suffix_ref = \$suffix;
 
-    my $sub_suffix = "_suffix_$$mode_ref";
+    $self->_sanity_input;
     $self->_gather_files;
+    my $sub_suffix = "_suffix_$$mode_ref";
     $self->$sub_suffix;
     $self->_move;
 }
 
+#
+# _sanity_input()
+#
+# Ensure that the interface input passes sanity;
+# if not, croak.
+#
+
+sub _sanity_input {
+    no warnings;
+    my $err_str;
+    {
+        unless ($$mode_ref eq 'char' || $$mode_ref eq 'num') {
+            $err_str = 'No mode specified.'; last;
+        }
+        unless ($$verbose_ref =~ /^0|1$/) {
+            $err_str = 'No verbosity specified.'; last;
+        }
+        unless ($$warn_ref =~ /^none|files|dirs|all$/) {
+            $err_str = 'No warn mode specified.'; last;
+        }
+        unless ($$override_ref =~ /^none|files|dirs|all$/) {
+            $err_str = 'No override mode specified.'; last;
+        }
+        unless ($$ident_ref =~ /\w/) {
+            $err_str = 'No subdir identifier specified.'; last;
+        }
+        unless ($$sep_ref) {
+            $err_str = 'No suffix separator specified.'; last;
+        }
+        if ($$mode_ref eq 'char') {
+            unless ($$case_ref eq 'lower' || $$case_ref eq 'upper') {
+                $err_str = 'No suffix case mode specified.'; last;
+            }
+        }
+        elsif ($$mode_ref eq 'num') {
+            unless ($$f_limit_ref =~ /\d/) {
+                $err_str = 'No file limit specified.'; last;
+            }
+            unless ($$f_sort_ref eq '+' || $$f_sort_ref eq '-') {
+                $err_str = 'No file sort mode specified.'; last;
+            }
+            unless ($$cont_num_ref eq 'y' || $$cont_num_ref eq 'n') {
+                $err_str = 'No continuation mode specified.'; last;
+            }
+            unless ($$l_req_ref =~ /\d/) {
+                $err_str = 'No suffix length specified.'; last;
+            }
+
+        }
+    }
+    croak $err_str if $err_str;
+    use warnings;
+}
+
 #
 # _gather_files()
 #
@@ -550,7 +609,8 @@ Assuming the source directory I</var/tmp/src> contains 5 files:
     +- ghi.tmp
     +- jkl.tmp
 
-the directory tree in the target directory I</var/tmp/target> will look as following:
+After splitting the directory tree in the target directory I</var/tmp/target> 
+will look as following:
 
 =head2 numeric splitting
 
@@ -580,11 +640,14 @@ the directory tree in the target directory I</var/tmp/target> will look as follo
 
 C<Perl 5.6.1>; C<File::Copy>, C<File::Path>, C<File::Spec>.
 
-=head1 CAVEATS
+=head1 CAVEATS & BUGS
 
 Recursive source directory processing is not supported;
 existing directories within the source directory will be ignored.
 
+Minus integer values in C<file_limit> and C<length> options
+cause an odd behavior at runtime.
+
 =head1 SEE ALSO
 
 perl(1)
